@@ -3,7 +3,7 @@ package Promise::XS::Loader;
 use strict;
 use warnings;
 
-our $VERSION = '0.01_01';
+our $VERSION = '0.01_02';
 
 require XSLoader;
 XSLoader::load('Promise::XS', $VERSION);
@@ -12,6 +12,8 @@ sub _convert_to_our_promise {
     my $thenable = shift;
     my $deferred= Promise::XS::Deferred::create();
     my $called;
+
+    local $@;
     eval {
         $thenable->then(sub {
             return if $called++;
@@ -28,7 +30,10 @@ sub _convert_to_our_promise {
         }
     };
 
-    undef $thenable;
+    # This promise is purely internal, so let’s not warn
+    # when its rejection is unhandled.
+    $deferred->clear_unhandled_rejection();
+
     return $deferred->promise;
 }
 
